/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/*
 *   Subroutine array_init
 *
 */
 
#include "decs.h"

void array_init()
{
	int i,j,k ;

        /* pointer shifting */
        rho =  (REAL (*) [NY+5][NZ+5])(& ( rhoas[3][3][3])) ;
        vx =   (REAL (*) [NY+5][NZ+5])(& (  vxas[3][3][3])) ;
        vy =   (REAL (*) [NY+5][NZ+5])(& (  vyas[3][3][3])) ;
        vz =   (REAL (*) [NY+5][NZ+5])(& (  vzas[3][3][3])) ;
        px =   (REAL (*) [NY+5][NZ+5])(& (  pxas[3][3][3])) ;
        py =   (REAL (*) [NY+5][NZ+5])(& (  pyas[3][3][3])) ;
        pz =   (REAL (*) [NY+5][NZ+5])(& (  pzas[3][3][3])) ;


	
        bx =   (REAL (*) [NY+5][NZ+5])(& (  bxas[3][3][3])) ;
        by =   (REAL (*) [NY+5][NZ+5])(& (  byas[3][3][3])) ;
        bz =   (REAL (*) [NY+5][NZ+5])(& (  bzas[3][3][3])) ;
	e  =   (REAL (*) [NY+5][NZ+5])(& (   eas[3][3][3])) ;
	work1 =   (REAL (*) [NY+4][NZ+4])(& (  work1as[2][2][2])) ;
	work2 =   (REAL (*) [NY+4][NZ+4])(& (  work2as[2][2][2])) ;
        work3 =   (REAL (*) [NY+4][NZ+4])(& (  work3as[2][2][2])) ;

	/* zero arrays */
	LOOPP(3,2,3,2,3,2)  rho[i][j][k] = 0. ;

	LOOPP(2,2,2,2,2,2) {
		 vx[i][j][k] = 0. ;
		 vy[i][j][k] = 0. ;
		 vz[i][j][k] = 0. ;
                 px[i][j][k] = 0. ;
                 py[i][j][k] = 0. ;
                 pz[i][j][k] = 0. ;


		 bx[i][j][k] = 0. ;
		 by[i][j][k] = 0. ;
		 bz[i][j][k] = 0. ;

		 e[i][j][k] = 0. ;
		 work1[i][j][k] = 0. ;
		 work2[i][j][k] = 0. ;
		 work3[i][j][k] = 0. ;
	}
	
}
