/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

#include "decs.h"

void dump(fp)
FILE *fp ;
{
	int i,j,k ;
	REAL vxa,vya,vza ;
	REAL Bxa,Bya,Bza,divb,p ;
	REAL eb,ek,eth,eg ;

	/* first line in dump file */
	fprintf(fp,"%d %d %d %g %g %g %g\n",NX,NY,NZ,t,Lx,Ly,Lz) ;

        for(i=0;i<NX;i++) 
        for(j=0;j<NY;j++) 
        for(k=0;k<NZ;k++) 
	{
		/* get everything centered on the zone */
                vxa = 0.5*(vx[i+1][j][k]+vx[i][j][k]) ;
                vya = 0.5*(vy[i][j+1][k]+vy[i][j][k]) ;
                vza = 0.5*(vz[i][j][k+1]+vz[i][j][k]) ;

                Bxa = 0.5*(bx[i+1][j][k]+bx[i][j][k]) ;
                Bya = 0.5*(by[i][j+1][k]+by[i][j][k]) ;
                Bza = 0.5*(bz[i][j][k+1]+bz[i][j][k]) ;

		fprintf(fp,"%d %d %d", i, j, k) ;
		fprintf(fp,"%15.10g ", rho[i][j][k]) ;
		fprintf(fp,"%15.10g %15.10g %15.10g ", vxa,vya,vza) ;
		fprintf(fp,"%15.10g %15.10g %15.10g ", Bxa,Bya,Bza) ;
		fprintf(fp,"\n") ;
	}

}




