/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/*
	produces a ppm file.  
*/

#include "decs.h"

void image(FILE *fp)
{
	double iq,liq,a,b,lmax,lmin,avg,rms, X,vayE ;
	void john_pal(double data, double min, double max,
                   int *pRed, int *pGreen, int *pBlue);
	int i,j,k, nx1, nx2 ;
	int red,green,blue ;
	static int slice = NZ/2 ;
        static int nghost = 2 ;
        static int nx = NX ;
        static int ny = NY ;
        static int ilo = -4 ;
        nx1 = nx + nghost - ilo ;
        nx2 = ny + 2*nghost ;

        double rhomax,rhomin;
#if MHDMODE3
#else	
	fprintf(fp,"P6\n%d %d\n255\n",nx1,nx2);
#endif
        /* density mapping is logarithmic, in 255 steps
           between e^lmax and e^lmin */
#if LINEAR || BZCOL 
        lmax = 0.01*pert*remi[0] ;
        lmin = -0.01*pert*remi[0] ;
        lmax = 1e-8 ;
        lmin = -1.e-8 ;
#elif RHOCOL || STRIPE
        lmax = 3. ;
        lmin = 1. ;
        //lmax = 0.2 ;
        //lmin = -0.2 ;
#elif FLOOP
        lmax = 0.08 ;
        lmin = -0.04 ;
#elif BY0
        lmax = 0. ;
        lmin = -q*W*va*tf ;
#endif

#if MHDMODE3
#else
	for(j=ny+nghost-1;j>=-nghost;j--)
        for(i=ilo;i<=nx+nghost-1;i++) {
        //for(j=NY-1;j>=0;j--)
        //for(i=0;i<=NX-1;i++) {
                X = (i + .5)*dx - .5 ;
#if LINEAR
                iq = (bx[i+1][j][slice]-bx[i][j][slice])/dx
                   + (by[i][j+1][slice]-by[i][j][slice])/dy
                   + (bz[i][j][slice+1]-bz[i][j][slice])/dz ;
                if(iq!=0.) iq = log(fabs(iq)) ;
                else iq = lmin ;
                iq = vx[i][j][slice] ;
                iq = rho[i][j][slice] - 1. ;
#elif BZCOL
                iq = bz[i][j][slice] ;
#elif RHOCOL || STRIPE
                iq = rho[i][j][slice] ;
#elif FLOOP
                iq = (by[i][j][slice] - by[i-1][j][slice])/dx - (bx[i][j][slice] - bx[i][j-1][slice])/dy ;
#elif BY0
                iq = by[i][j][slice] ;
#endif
                john_pal(iq,lmin,lmax,&red,&green,&blue);
                fputc(red,fp);
                fputc(green,fp);
                fputc(blue,fp);
        }

#endif

#if MHDMODE3

	/* slice choice */
	k = NZ/2 ;

        rhomax = 0.;
        rhomin = 1.;

	/* ppm header */
	fprintf(fp,"P6\n%d %d\n255\n",NX,NY);

	/* density mapping is linear between max dens and min */
	for(i=0;i<NX;i++)
	for(j=0;j<NY;j++) {
		iq = rho[i][j][k] ;
		avg += iq ;
		rms += iq*iq ;
                if(iq>rhomax) rhomax = iq;
                if(iq<rhomin) rhomin = iq;
	}
	avg /= NX*NY ;
	rms /= NX*NY ;
	rms += 1.e-4 ;
	rms = sqrt(rms - avg*avg) ;

	fprintf(stderr,"avg,rms: %g %g\n",avg,rms) ;
        fprintf(stderr,"rhomax, rhomin: %g %g \n",rhomax, rhomin);

	lmax = avg + 3.*rms ;
	lmin = avg - 3.*rms ;

	a = 255./(lmax - lmin) ;
	for(j=NY-1;j>=0;j--) 
	for(i=0;i<NX;i++) {
		iq = rho[i][j][k] ;
		liq = a*(iq - lmin) ;
		if(liq > 255.) liq = 255. ;
		if(liq < 0.) liq = 0. ;

		john_pal(iq,lmin,lmax,&red,&green,&blue);
      		fputc(red,fp);
      		fputc(green,fp);
      		fputc(blue,fp);
	}
#endif
}


void john_pal(double data, double min, double max,
                   int *pRed, int *pGreen, int *pBlue){
  double max_min = max - min;
  double a, b, c, d, e, f;
  double x, y;

  if(max_min > 0.0){ 
    x = (data - min)/(max_min); 
    
    /* ========== Red ============ */
    a = 4.0*x - 1.52549019607844;
    b = 4.52941176470589 - 4.0*x;
    y = a < b ? a : b;
    *pRed = (int)(255.0*y);
    *pRed = *pRed >   0 ? *pRed :   0;
    *pRed = *pRed < 255 ? *pRed : 255;

    /* ========== Green ========== */
    a = 4.0*x - 0.521568627450979;
    b = 2.52549019607844 - 4.0*x;
    c = a < b ? a : b;
    d = 4.0*x - 1.53725490196073;
    e = 3.52941176470581 - 4.0*x;
    f = d < e ? d : e;
    y = c > f ? c : f;
    *pGreen = (int)(255.0*y);
    *pGreen = *pGreen >   0 ? *pGreen :   0;
    *pGreen = *pGreen < 255 ? *pGreen : 255;

    /* ========== Blue =========== */
    a = 4.0*x + 0.498039215686276;
    b = 2.50980392156862 - 4.0*x;
    y = a < b ? a : b;
    *pBlue = (int)(255.0*y);
    *pBlue = *pBlue >   0 ? *pBlue :   0;
    *pBlue = *pBlue < 255 ? *pBlue : 255;
  }
  else{
    *pRed = *pGreen = *pBlue = (data > max ? 255 : 0);
  }

  return;
}
