/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/* initialize all variables */

#include "decs.h"


void init()
{
	int i,j,k ;
	void bound_var(REAL (* var)[NY+5][NZ+5], REAL tcurr, int sym) ;
	double ranc() ;
	void array_init() ;
	REAL X,Y,Z,R ;
	REAL w,K,XP,YP,ZP,amp,sig2 ;
	REAL b,discr,omega,omega2,kappa2,va,k0 ;
	REAL (*Az)[NY+4][NZ+4] ;
	REAL eps ;
        FILE *outfile;




	/* here are the real adjustable parameters */
	Lx = 8. ;
	Ly = 8.*M_PI ;
	Lz = 2. ;
	A0 = 0.5 ;
	drive = 0. ;
	W = 1. ;
	Wz = 0. ;

	/* here are the seldom adjusted parameters */
	q = 1.5 ;
	kappa2 = 2.*(2. - q)*W*W ;
	cs = 1.0000 ;
	c = 10.*cs ;
	gam = 1.00001;
	//gam = 1.0;

	/* numerical parameters */
	cour = 0.9 ;
	nu_vnr = 1. ;
	nu_l = 0. ;

	/* some initializations */
	dx = Lx/NX ;
	dy = Ly/NY ;
	dz = Lz/NZ ;
	dV = dx*dy*dz ;
	dt = 0.01 ;  /* needs initial value */
	t = 0. ;

	/* zero arrays & shift pointers */
	array_init() ;

	/* problem set up */
   
        B0z = sqrt(15.)/(32.*M_PI);
	tf = 100. ;
        eps = 0.01;





	/* set primitive variables */
	LOOP {
		X = (i + 0.5)*dx - 0.5*Lx ;
		XP = i*dx - 0.5*Lx ;
		Y = (j + 0.5)*dy - 0.5*Ly ;
		YP = j*dy - 0.5*Ly ;
		Z = (k + 0.5)*dz - 0.5*Lz ;
		ZP = k*dz - 0.5*Lz ;
		
		vx[i][j][k] = 0. + eps*ranc(0) ;
#if SWEEPYM             
                vy[i][j][k] = eps*ranc(0);
#else      
                vy[i][j][k] = -q*W*X + eps*ranc(0);
#endif
		vz[i][j][k] = 0. + eps*ranc(0);

		bx[i][j][k] = 0. ;
		by[i][j][k] = 0. ;
		bz[i][j][k] = B0z*sin(M_PI*X) ;
		
		rho[i][j][k] = 1. ;
                e[i][j][k] = 1./(gam-1.);

	}

	DTd = tf/20. ;	/* dumping frequency */
	DTi = tf/1000. ; /* image frequency */
	DTl = tf/4000. ; /* log frequency */


	/* enforce boundary conditions */
	bound_var(rho,t,SYMMETRIC) ;
	bound_var(vx,t,SYMMETRIC) ;
	bound_var(vy,t,SYMMETRIC) ;
	bound_var(vz,t,ANTISYMMETRIC) ;

	bound_var(by,t,SYMMETRIC) ;
	bound_var(bz,t,ANTISYMMETRIC) ;
        bound_var(bx,t,SYMMETRIC) ;

	bound_var(e,t,SYMMETRIC) ;
	
        



}
