/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

#include "decs.h"
#include "defs.h"

main(int argc, char *argv[])
{
	void init(),timestep(),stepvar(),dump(),diag() ;
	REAL tnext ;
	int seed,i,j,k ;

	tnext = 0. ;
	nstep = 0 ;

	if(argc < 1) {
		fprintf(stderr,"usage: bend3d \n") ;
		exit(0) ;
	}

	/* perform initializations */
	init() ;

	/* do initial diagnostics */
	diag(0) ;
        

	while(t < tf) 
	  {

		/* find timestep */
		timestep() ;

		/* step variables forward in time */
		stepvar() ;


		/* perform diagnostics */
		
		if(t > tnext) {
			diag(1) ;
			tnext += DTl ;
		
		}
		
		//if(nstep == 64) exit(0) ;

		fprintf(stderr,"t,dt: %10.5g %10.5g\n",t,dt) ;
		nstep++ ;
	}

	/* do final diagnostics */
	diag(2) ;

	fprintf(stderr,"nstep: %d\n",nstep) ;
	fprintf(stderr,"zone cycles: %g\n",(double)(NX*NY*NZ)*
		(double)(nstep)) ;

	return(0) ;
}
