/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/* 
   Do transport step.  Order of sweep direction is
   varied from step to step. 

    last modified: xg Mar 30, 2007
*/

#include "decs.h"




void step_trans_new2c()
{
	void sweepx_new2c() ;
	void sweepy_new2c() ;
	void sweepym() ;
	void sweepz_new2c() ;
        int i,j,k;
       
	LOOPP(2,2,2,2,2,2)
          {

            px[i][j][k] = 0.5*(rho[i-1][j][k]+rho[i][j][k])*vx[i][j][k] ;
            py[i][j][k] = 0.5*(rho[i][j-1][k]+rho[i][j][k])*vy[i][j][k] ;
            pz[i][j][k] = 0.5*(rho[i][j][k-1]+rho[i][j][k])*vz[i][j][k] ;
            
          }
	
	if(nstep%6 == 0) { sweepx_new2c() ; 
           sweepy_new2c() ; sweepz_new2c() ;  }
	if(nstep%6 == 1) { sweepz_new2c() ; sweepx_new2c() ; sweepy_new2c() ; }
	if(nstep%6 == 2) { sweepy_new2c() ; sweepz_new2c() ; sweepx_new2c() ; }
	if(nstep%6 == 3) { sweepx_new2c() ; sweepz_new2c() ; sweepy_new2c() ; }
	if(nstep%6 == 4) { sweepy_new2c() ; sweepx_new2c() ; sweepz_new2c() ; }
	if(nstep%6 == 5) { sweepz_new2c() ; sweepy_new2c() ; sweepx_new2c() ; }

#if SWEEPYM
        if(NY > 1 && q!=0.) sweepym() ;
#endif

	
	LOOPP(1,2,0,0,0,0)
          vx[i][j][k] = 2.*px[i][j][k]/(rho[i][j][k]+rho[i-1][j][k]) ;

         	
	 LOOPP(2,2,0,0,0,0) 
          {
            
            vy[i][j][k] = 2.*py[i][j][k]/(rho[i][j][k]+rho[i][j-1][k]) ;
            vz[i][j][k] = 2.*pz[i][j][k]/(rho[i][j][k]+rho[i][j][k-1]) ;
          }
	
	
	bound_var(vx,t+dt,SYMMETRIC) ;
    bound_var(vy,t+dt,SYMMETRIC) ;
    bound_var(vz,t+dt,ANTISYMMETRIC) ;
	


}
