/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/* 
 * Function sweepx
 * 
 * Transport step; sweep in x direction
 * 
 * bound 5 time: rho, vx, vy, vz, e
 *
 *
 * mpi version last modified: xg Mar 30, 2007
 * 
 *
 */
#include "decs.h"







void sweepx_new2c()
{
	REAL vpp,mdotp ;
	REAL (*dq)[NY+4][NZ+4], (*mdot)[NY+4][NZ+4], (*fl)[NY+4][NZ+4] ;
	int i,j,k ;
        FILE *outfile;


	dq = work1 ;
	mdot = work2 ;
	fl = work3 ;

	/* create dimensionless transport variable */
	LOOPP(2,2,2,2,2,2) vx[i][j][k] *= (dt/dx) ;
  
	/* first do mass */
	LOOPP(2,1,1,0,1,0) 
	  {
	    dq[i][j][k] = slope_lim(rho[i-1][j][k],rho[i][j][k],rho[i+1][j][k]) ;
	  }
	LOOPP(1,1,1,0,1,0) 
	  {
	    mdot[i][j][k] = (vx[i][j][k] > 0.) ?
	      vx[i][j][k]*(rho[i-1][j][k] + (1. - vx[i][j][k])*dq[i-1][j][k]) :
	      vx[i][j][k]*(rho[i][j][k] - (1. + vx[i][j][k])*dq[i][j][k]) ;
	  }



  	LOOPP(1,1,0,0,0,0) 
	  {
	    dq[i][j][k] = slope_lim(e[i-1][j][k],
				    e[i][j][k],
				    e[i+1][j][k]) ;
	  }
	
	LOOPP(0,1,0,0,0,0) 
	  {
	    fl[i][j][k] = (vx[i][j][k] > 0.) ?
	      vx[i][j][k]*(e[i-1][j][k] + (1. - vx[i][j][k])*dq[i-1][j][k]) :
	      vx[i][j][k]*(e[i][j][k] - (1. + vx[i][j][k])*dq[i][j][k]) ;
	  }
	
	LOOP 
	  e[i][j][k] += -(fl[i+1][j][k]-fl[i][j][k]) ;

	/* vx: because of different centering, indices differ */
	LOOPP(1,1,0,0,0,0) 
	  {
	    dq[i][j][k] = slope_lim(px[i-1][j][k],px[i][j][k],px[i+1][j][k]) ;
	  }
	LOOPP(1,0,0,0,0,0) 
	  {
	    vpp = 0.5*(vx[i+1][j][k]+vx[i][j][k]) ;
	    fl[i][j][k] = (vpp > 0.) ?
	      vpp*(px[i][j][k] + (1. - vpp)*dq[i][j][k]) :
	      vpp*(px[i+1][j][k] - (1. + vpp)*dq[i+1][j][k]) ;
	  }
	LOOP 
	  px[i][j][k] += -(fl[i][j][k]-fl[i-1][j][k]) ;
	
	/* vy */
	LOOPP(1,1,0,0,0,0) 
	  {
	    dq[i][j][k] = slope_lim(py[i-1][j][k],py[i][j][k],py[i+1][j][k]) ;
	  }
	LOOPP(0,1,0,0,0,0) 
	  {
	    vpp = 0.5*(vx[i][j][k]+vx[i][j-1][k]) ;
	    fl[i][j][k] = (vpp > 0.) ? 
	      vpp*(py[i-1][j][k] + (1. - vpp)*dq[i-1][j][k]) :
	      vpp*(py[i][j][k] - (1. + vpp)*dq[i][j][k]) ;
	  }
	LOOP 
	  py[i][j][k] += -(fl[i+1][j][k]-fl[i][j][k]) ;

	/* vz */
	LOOPP(1,1,0,0,0,0) 
	  {
	    dq[i][j][k] = slope_lim(pz[i-1][j][k],pz[i][j][k],pz[i+1][j][k]) ;
	  }
	LOOPP(0,1,0,0,0,0) 
	  {
	    vpp = 0.5*(vx[i][j][k]+vx[i][j][k-1]) ;
	    fl[i][j][k] = (vpp > 0.) ? 
	      vpp*(pz[i-1][j][k] + (1. - vpp)*dq[i-1][j][k]) :
	      vpp*(pz[i][j][k] - (1. + vpp)*dq[i][j][k]) ;
	  }
	LOOP 
	  pz[i][j][k] += -(fl[i+1][j][k]-fl[i][j][k]) ;
	
	LOOP
	  {
	    rho[i][j][k] += -(mdot[i+1][j][k] - mdot[i][j][k]) ;
	     if(rho[i][j][k] < MIN) {
              fprintf(stderr,"x small density: %d %g\n",i,rho[i][j][k]) ;
	     }
	  }


        LOOPP(2,2,2,2,2,2) vx[i][j][k] *= (dx/dt);    
	
	bound_var(rho,t+dt,SYMMETRIC) ;
	bound_var(e,t+dt,SYMMETRIC) ;
      
      
	
	bound_var(px,t+dt,SYMMETRIC) ;
    bound_var(py,t+dt,SYMMETRIC) ;
    bound_var(pz,t+dt,ANTISYMMETRIC) ;

	
 
 
}	


