/***********************************************************************************
    Copyright 2011 Bryan Johnson, Xiaoyue Guan & Charles F. Gammie

                  mthreed  version 1.0   (released Jun 2, 2011)

    This file is part of mthreed. mthreed adopts a ZEUS-like scheme to solve 
    magnetohydrodynamic equations of motion in a shearing sheet. It uses obital 
    advection to ensure fast and accurate integration in a large shearing box. 
    

    You are morally obligated to cite the following paper in his/her
    scientific literature that results from use of any part of mthreed:

    [1] Johnson, B.M., Guan, X. \& Gammie, C.F. \ 2008, Astrophysical Journal, 
        Supplement, 177, 373


    The latest version of the mthreed is available on our code distribution
    website:
    http://rainman.astro.uiuc.edu/codelib/

    mthreed is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    mthreed is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mthreed; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

***********************************************************************************/

/* 
 * Function timestep
 * 
 *
 * mpi version last modified: xg Apr 11, 2007
 * 
 *
 */
#include "decs.h"

void timestep() 
{
	int i,j,k,imax,jmax,kmax ;
	REAL u,va,X ;
	REAL idt1,idt2,idt3,idt4,idt5,idt6,idt7,idt8,idt9 ;
	REAL dtinv ;
	REAL dtinv_max,dt3m,dt4m,dt5m,dt1m ;
	REAL dv,d,vxpot,vypot,dvy,fast ;
	static REAL dtlast ;
	void dump() ;


	FILE *dump_file;

	if(dx <= dy && dx <= dz) d = dx ;
	else if (dy <= dx && dy <= dz) d = dy ;
	else d = dz ;

        /* SSBC timestep criterion */
	idt2 = 2.*q*W ;
	idt2 *= idt2 ;
	idt2 = 0. ;

	dtinv_max = 0. ;
	dtlast = dt ;
	LOOP 
	  {
	    if(rho[i][j][k] < 0) 
	      {		
		     fprintf(stderr,"negative density error at i=%d, j=%d k=%d, \n", i, j, k);

             dump_file = fopen("termin.dump","w");
		     if(dump_file == NULL)
		       {
		          fprintf(stderr,"error opening termin.dump\n") ;
		          exit(1) ;
               }

		dump(dump_file) ;
		exit(4) ;
	      }
	    
	  
	    
	    if(fabs(gam - 1.) > 1.e-6) 
            cs = sqrt(gam*(gam-1.)*e[i][j][k]/rho[i][j][k]) ;
	    
	    /* fast speed; not centered */
	    fast = cs*cs +
	      (bx[i][j][k]*bx[i][j][k] + by[i][j][k]*by[i][j][k] + bz[i][j][k]*bz[i][j][k])/rho[i][j][k]  ;
	    idt1 = sqrt(fast);	
	 
	    
	
	    /* x-velocity */
	    idt3 = (fabs(vx[i][j][k]) + idt1)/dx ;
            
        idt3 *= idt3 ;
	
	    /* y-velocity */
	    idt4 = (fabs(vy[i][j][k]) + idt1)/dy ;

	    idt4 *= idt4 ;
	
	    /* z-velocity */
	    idt5 = (fabs(vz[i][j][k]) + idt1)/dz ;

	    idt5 *= idt5 ;
	



	    dtinv = idt3 + idt4 + idt5 ;

	    if(dtinv > dtinv_max) 
	      {
              dtinv_max = dtinv ;
              imax = i ;
              jmax = j ;
              kmax = k ;
              dt3m = idt3 ;
              dt4m = idt4 ;
              dt5m = idt5;
              dt1m = idt1;
	      }
	  }
	
	



	dt = cour/sqrt(dtinv_max)/sqrt(3.) ;


	/* don't increase timestep by too much */
	if(dt > 1.3*dtlast) dt = 1.3*dtlast ;

	/* don't step beyond end of run */
	if(t + dt > tf) dt = tf - t ;
}

